@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2014 Olivier Girondel
+ *  Copyright 1994-2016 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -83,8 +83,8 @@ SDL_refresh_32bpp(Context_t *ctx, SDL_Surface *sc)
 
 #ifndef FIXED
   if (NULL == sws_context)
-    sws_context = sws_getContext(WIDTH, HEIGHT, PIX_FMT_RGB32,
-				 out_width, out_height, PIX_FMT_BGR32,
+    sws_context = sws_getContext(WIDTH, HEIGHT, AV_PIX_FMT_RGB32,
+				 out_width, out_height, AV_PIX_FMT_BGR32,
 				 SWS_FAST_BILINEAR, NULL, NULL, NULL);
   if (NULL == sws_context)
     xerror("sws_getContext\n");
