@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2014 Olivier Girondel
+ *  Copyright 1994-2016 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -321,8 +321,8 @@ gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const
   struct SwsContext *sws_context = NULL;
   int ret;
 
-  sws_context = sws_getContext(width, height, PIX_FMT_GRAY8,
-			       WIDTH, HEIGHT, PIX_FMT_GRAY8,
+  sws_context = sws_getContext(width, height, AV_PIX_FMT_GRAY8,
+			       WIDTH, HEIGHT, AV_PIX_FMT_GRAY8,
 			       SWS_FAST_BILINEAR, NULL, NULL, NULL);
   if (NULL == sws_context)
     xerror("sws_getContext\n");
