@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2014 Olivier Girondel
+ *  Copyright 1994-2016 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -198,7 +198,7 @@ Input_do_fft(Input_t *input)
 }
 
 
-inline double
+static inline double
 Input_clamp(const double val)
 {
   if (val < -1.0) return -1.0;
