@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2014 Olivier Girondel
+ *  Copyright 1994-2016 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -148,7 +148,7 @@ Perceptron_load(__attribute__ ((unused)) Perceptron_t *per, const char *file)
 }
 
 
-inline float sygmoide(float x) { return tanhf(x); }
+static inline float sygmoide(float x) { return tanhf(x); }
 
 
 float
